package ca.javajeff.lexan;

/**
 *  An exception that occurs while lexing.
 *
 *  @author Jeff Friesen
 */

public final class LexException extends Exception
{
   private int badCharIndex;

   private String text;

   /**
    *  Initialize a lex exception to a message, the text that was being lexed,
    *  and the index of the character about to be lexed that triggered the 
    *  exception.
    *
    *  @param msg reason for the exception
    *
    *  @param text the text being lexed
    *
    *  @param badCharIndex index of character about to be lexed that triggered
    *         the exception
    */

   public LexException(String msg, String text, int badCharIndex)
   {
      super(msg);
      this.text = text;
      this.badCharIndex = badCharIndex;
   }

   /**
    *  Get this exception's bad character index.
    *
    *  @return bad character index
    */

   public int getBadCharIndex()
   {
      return badCharIndex;
   }

   /**
    *  Get this exception's text being lexed.
    *
    *  @return text being lexed
    */

   public String getText()
   {
      return text;
   }
}