package ca.javajeff.lexan;

import java.util.regex.Pattern;

/**
 *  A name with a regex attribute.
 *
 *  @author Jeff Friesen
 */

public final class Token
{
   private Pattern pattern;

   private String name;

   /**
    *  Initialize a token to a name/regex pair. The regex is compiled into a 
    *  pattern, which is stored instead of the regex to boost performance.
    *
    *  @param name token's name
    *
    *  @param regex regular expression that determines which strings associate
    *         with the token
    */

   public Token(String name, String regex)
   {
      this.name = name;
      pattern = Pattern.compile("^(" + regex + ")");
   }

   /**
    *  Get this token's pattern.
    *
    *  @return pattern
    */

   Pattern getPattern()
   {
      return pattern;
   }

   /**
    *  Convert this token to its string representation.
    *
    *  @return string representation of token
    */

   @Override
   public String toString()
   {
      return name;
   }
}